@@ -1,8 +1,10 @@
 import json
 from flask import Flask, request
 from rainbond_python.parameter import Parameter
+from rainbond_python.error_handler import error_handler
 
 app = Flask(__name__)
+error_handler(app)
 
 
 @app.route('/demo/1.0/demo', methods=['GET', 'POST', 'PUT', 'DELETE'])
