@@ -94,8 +94,11 @@ class DBConnect():
         if len(columns):
             for i in range(len(columns)):
                 # 整理请求参数中的筛选项字典
-                if filtered_value[i].strip() != '':
-                    find_dict[columns[i]] = {'$regex': filtered_value[i]}
+                if type(filtered_value[i]) == int:
+                    find_dict[columns[i]] = filtered_value[i]
+                else:
+                    if filtered_value[i].strip() != '':
+                        find_dict[columns[i]] = {'$regex': filtered_value[i]}
                 # 整理请求参数中的筛排序列表
                 sort_value = sort_order[i].strip()
                 if sort_value == 'asc':
